// THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
//! This module provides terms for `prefix` vocabulary
//!
//! This module requires `ns-prefix` feature to be enabled.
//!
//! ## Vocabulary:
//!
//! |||
//! |-----|-----|
//! |**Title**||
//! |**Prefix**|prefix|
//! |**Namespace base IRI**|<http://qudt.org/vocab/prefix/>|
//! |**Description**||
//! |**Is defined by**|<http://qudt.org/2.1/vocab/prefix>|
//!

use crate::namespace;

namespace!(
    "http://qudt.org/vocab/prefix/",;
    /// ``: 
    NAMESPACE_BASE, "",
    /// `Atto`: 
    Atto, "Atto",
    /// `Centi`: 
    Centi, "Centi",
    /// `Deca`: 
    Deca, "Deca",
    /// `Deci`: 
    Deci, "Deci",
    /// `Deka`: 
    Deka, "Deka",
    /// `Exa`: 
    Exa, "Exa",
    /// `Exbi`: 
    Exbi, "Exbi",
    /// `Femto`: 
    Femto, "Femto",
    /// `Gibi`: 
    Gibi, "Gibi",
    /// `Giga`: 
    Giga, "Giga",
    /// `Hecto`: 
    Hecto, "Hecto",
    /// `Kibi`: 
    Kibi, "Kibi",
    /// `Kilo`: 
    Kilo, "Kilo",
    /// `Mebi`: 
    Mebi, "Mebi",
    /// `Mega`: 
    Mega, "Mega",
    /// `Micro`: 
    Micro, "Micro",
    /// `Milli`: 
    Milli, "Milli",
    /// `Nano`: 
    Nano, "Nano",
    /// `Pebi`: 
    Pebi, "Pebi",
    /// `Peta`: 
    Peta, "Peta",
    /// `Pico`: 
    Pico, "Pico",
    /// `Tebi`: 
    Tebi, "Tebi",
    /// `Tera`: 
    Tera, "Tera",
    /// `Yobi`: 
    Yobi, "Yobi",
    /// `Yocto`: 
    Yocto, "Yocto",
    /// `Yotta`: 
    Yotta, "Yotta",
    /// `Zebi`: 
    Zebi, "Zebi",
    /// `Zepto`: 
    Zepto, "Zepto",
    /// `Zetta`: 
    Zetta, "Zetta"
);
